@@ -22,6 +22,7 @@ import csv
 import datetime
 import hashlib
 import inspect
+import imghdr
 import os
 import requests
 import time
@@ -147,8 +148,27 @@ def download(url, filename):
             url = urllib.parse.urlparse(url)
             url = url.scheme + "://" + url.netloc + urllib.parse.quote(url.path)
             urllib.request.urlretrieve(url.replace(' ', '+'), filename)
+        return filename
     except Exception as e:
         logger.error("Error when downloading/writing file %s error %s ..." % (filename, e))
+    url_extension = image_extension(url)
+    real_extension = imghdr.what(filename)
+    if real_extension != url_extension:
+        file_hash = filename.split('.')[0]
+        try:
+            res = all(ord(c) < 128 for c in url)
+            if res:
+                urllib.request.urlretrieve(url.replace(' ', '+'), file_hash + '.' + real_extension)
+            else:
+                url = urllib.parse.urlparse(url)
+                url = url.scheme + "://" + url.netloc + urllib.parse.quote(url.path)
+                urllib.request.urlretrieve(url.replace(' ', '+'), file_hash + '.' + real_extension)
+
+            return file_hash + '.' + real_extension
+        except Exception as e:
+            logger.error("Error when downloading/writing file %s error %s ..."
+                         % (file_hash + '.' + real_extension, e))
+            return None
 
 
 def can_be_downloaded(url):
@@ -232,14 +252,8 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
     hash_files = ""
     for url in urls.split(' '):
         hash_file = get_remote_file_hash(url)
-        if ('.jpg' in url) or ('.JPG' in url):
-            filename = hash_file + ".jpg"
-        elif ('.png' in url) or ('.PNG' in url):
-            filename = hash_file + ".png"
-        elif ('.jpeg' in url) or ('.JPEG' in url):
-            filename = hash_file + ".jpeg"
-        else:
-            filename = hash_file
+        extention = image_extension(url)
+        filename = hash_file + '.' + extention
         fichier = path_out + '/' + filename
         resized_fichier = resized_path + '/' + filename
 
