@@ -136,6 +136,10 @@ def delete_project(customer, customer_type, api_project, project_name, project_i
                                                   project_name
         streams_path_3 = STREAMS_S3 + customer_type + '/' + customer + '/similars/' + \
                                                   project_name
+        training_path_project_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
+                                          project_name
+        training_path_s3_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
+                                     project_name
         try:
             if os.path.isdir(input_path_project_to_delete):
                 move_directory(input_path_s3, 'deleted_project')
@@ -153,6 +157,10 @@ def delete_project(customer, customer_type, api_project, project_name, project_i
                 move_directory(streams_path_3, 'deleted_project')
                 shutil.rmtree(streams_path_project_similars_to_delete)
                 logger.info("streams path similars -------- DELETED")
+            if os.path.isdir(training_path_project_to_delete):
+                move_directory(training_path_s3_to_delete, 'deleted_project')
+                shutil.rmtree(training_path_project_to_delete)
+                logger.info("training classification path similars -------- DELETED")
             return 1
         except Exception as e:
             logger.info("Error deleting similars project %s %s " % (project_name, e))
